@@ -2,8 +2,8 @@
  * file: $RCSfile: board.c,v $
  * author: Pawel S. Veselov
  * created: 2002/10/06
- * last modified: $Date: 2006/07/08 09:15:17 $
- * version: $Revision: 1.3 $
+ * last modified: $Date: 2006/10/02 03:41:58 $
+ * version: $Revision: 1.6 $
  */
 
 #include <clines/sysi.h>
@@ -19,16 +19,21 @@ void reset(board * b) {
     b->con = 1;
 }
 
-void add(board * b) {
+int add(board * b) {
 
     int i;
-    int p[b->nev];
+    int nev = b->played?b->nev:b->first_nev;
+    int p[nev];
     int * ptr = b->board;
-    // int sz = b->w * b->h * sizeof(int);
 
     b->rec->len = 0;
+    b->played = 1;
 
-    for (i=0; i<b->nev; i++) {
+    if (b->av < nev) {
+        return 0;
+    }
+
+    for (i=0; i<nev; i++) {
 
 	int j;
 
@@ -52,20 +57,21 @@ void add(board * b) {
 	int j;
 	while ((*(ptr++)));
 	ptr--;
-	for (j=0; j<b->nev; j++) {
+	for (j=0; j<nev; j++) {
 	    if (p[j]/b->mc == i) {
-		*ptr = p[j] % b->mc + 1;
+		*ptr = p[j] % b->mc + 2;
 		render1(b, ptr - b->board, -1);
-		b->rec->path[b->rec->len++] = (unsigned char)(ptr-b->board);
+		b->rec->path[b->rec->len++] = (int)(ptr-b->board);
 	    }
 	}
 	ptr++;
     }
 
-    b->av -= b->nev;
+    b->av -= nev;
+    return nev+1;
 }
 
 int myrand(int lim) {
-    // from linux rand(3)
+    // from linux rand(3) manual page
     return (int) ((float)lim*rand()/(RAND_MAX+1.0));
 }
