@@ -2,8 +2,8 @@
  * file: $RCSfile: sysi.h,v $
  * author: Pawel S. Veselov
  * created: 2002/10/06
- * last modified: $Date: 2006/07/09 07:47:59 $
- * version: $Revision: 1.7 $
+ * last modified: $Date: 2006/08/28 20:31:14 $
+ * version: $Revision: 1.10 $
  */
 
 #ifndef _CLINES_SYSI_H_
@@ -19,6 +19,22 @@
 
 #include "clines-config.h"
 
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+
+#ifdef HAVE_DIRENT_H
+#include <dirent.h>
+#endif
+
+#ifdef HAVE_PWD_H
+#include <pwd.h>
+#endif
+
 #ifdef HAVE_STDIO_H
 #include <stdio.h>
 #endif
@@ -31,10 +47,18 @@
 #include <strings.h>
 #endif
 
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
 
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #ifdef CURSES_CURSES
 #include <curses.h>
 #endif
@@ -59,6 +83,15 @@
 #include <unistd.h>
 #endif
 
+#ifdef HAVE_GPM_H   // we only need term.h to resolve GPM's mess
+#ifdef HAVE_TERM_H
+#include <term.h>
+#ifdef buttons
+#undef buttons
+#endif // who was so smart to define sys wide 'buttons' define ???
+#endif
+#endif
+
 #if defined(HAVE_TIME_H) && defined(HAVE_SYS_TIME_H) && defined(TIME_WITH_SYS_TIME)
 #include <time.h>
 #include <sys/time.h>
@@ -80,6 +113,10 @@
 #include <gpm.h>
 #endif
 
+#ifdef HAVE_CTYPE_H
+#include <ctype.h>
+#endif
+
 #else
 #include <stdio.h>
 #include <string.h>
@@ -89,7 +126,10 @@
 #include <unistd.h>
 #include <time.h>
 #include <sys/time.h>
+#include <sys/types.h>
+#include <dirent.h>
 #include <stdarg.h>
+#include <ctype.h>
 #endif
 
 #endif
